@@ -877,6 +877,6 @@ final class LeadEvents
 
     public function getSourceContext(): Source
     {
-        return new Source("", "@bundles/LeadBundle/LeadEvents.php", "/var/www/mautic-ktn/app/bundles/LeadBundle/LeadEvents.php");
+        return new Source("", "@bundles/LeadBundle/LeadEvents.php", "/var/www/html/mauticGIT-Test/app/bundles/LeadBundle/LeadEvents.php");
     }
 }
