@@ -742,6 +742,6 @@ class Campaign extends FormEntity implements PublishStatusIconAttributesInterfac
 
     public function getSourceContext(): Source
     {
-        return new Source("", "@bundles/CampaignBundle/Entity/Campaign.php", "/var/www/mautic-ktn/app/bundles/CampaignBundle/Entity/Campaign.php");
+        return new Source("", "@bundles/CampaignBundle/Entity/Campaign.php", "/var/www/html/mauticGIT-Test/app/bundles/CampaignBundle/Entity/Campaign.php");
     }
 }
