@@ -896,6 +896,6 @@ class PublicController extends CommonFormController
 
     public function getSourceContext(): Source
     {
-        return new Source("", "@bundles/EmailBundle/Controller/PublicController.php", "/var/www/mautic-ktn/app/bundles/EmailBundle/Controller/PublicController.php");
+        return new Source("", "@bundles/EmailBundle/Controller/PublicController.php", "/var/www/html/mauticGIT-Test/app/bundles/EmailBundle/Controller/PublicController.php");
     }
 }
