@@ -233,6 +233,6 @@ class __TwigTemplate_a470f6e3277c7840f3e9d98817ac4d6c extends Template
 
     public function getSourceContext(): Source
     {
-        return new Source("", "@themes/oxygen/html/page.html.twig", "/var/www/mautic-ktn/themes/oxygen/html/page.html.twig");
+        return new Source("", "@themes/oxygen/html/page.html.twig", "/var/www/html/mauticGIT-Test/themes/oxygen/html/page.html.twig");
     }
 }
