@@ -389,6 +389,6 @@ class __TwigTemplate_40f70974a65be4242021ac9a06c3e110 extends Template
 
     public function getSourceContext(): Source
     {
-        return new Source("", "@MauticLead/Auditlog/_list.html.twig", "/var/www/mautic-ktn/app/bundles/LeadBundle/Resources/views/Auditlog/_list.html.twig");
+        return new Source("", "@MauticLead/Auditlog/_list.html.twig", "/var/www/html/mauticGIT-Test/app/bundles/LeadBundle/Resources/views/Auditlog/_list.html.twig");
     }
 }
