@@ -815,6 +815,6 @@ class AjaxController extends CommonController
 
     public function getSourceContext(): Source
     {
-        return new Source("", "@bundles/CoreBundle/Controller/AjaxController.php", "/var/www/mautic-ktn/app/bundles/CoreBundle/Controller/AjaxController.php");
+        return new Source("", "@bundles/CoreBundle/Controller/AjaxController.php", "/var/www/html/mauticGIT-Test/app/bundles/CoreBundle/Controller/AjaxController.php");
     }
 }
