@@ -443,6 +443,6 @@ class __TwigTemplate_1f6d1aaf408aee0ba85e6b21c1733bbb extends Template
 
     public function getSourceContext(): Source
     {
-        return new Source("", "@themes/fpoe_kaernten_theme_full_final_v2/html/email.html.twig", "/var/www/mautic-ktn/themes/fpoe_kaernten_theme_full_final_v2/html/email.html.twig");
+        return new Source("", "@themes/fpoe_kaernten_theme_full_final_v2/html/email.html.twig", "/var/www/html/mauticGIT-Test/themes/fpoe_kaernten_theme_full_final_v2/html/email.html.twig");
     }
 }
