@@ -237,6 +237,6 @@ class __TwigTemplate_8ac59284d91eaf3bb97761968959fc9c extends Template
 
     public function getSourceContext(): Source
     {
-        return new Source("", "@MauticLead/Batch/channel.html.twig", "/var/www/mautic-ktn/app/bundles/LeadBundle/Resources/views/Batch/channel.html.twig");
+        return new Source("", "@MauticLead/Batch/channel.html.twig", "/var/www/html/mauticGIT-Test/app/bundles/LeadBundle/Resources/views/Batch/channel.html.twig");
     }
 }
