@@ -426,6 +426,6 @@ class __TwigTemplate_5220350f171d3ee09714ee7f93fcd644 extends Template
 
     public function getSourceContext(): Source
     {
-        return new Source("", "@themes/fresh-center/html/page.html.twig", "/var/www/mautic-ktn/themes/fresh-center/html/page.html.twig");
+        return new Source("", "@themes/fresh-center/html/page.html.twig", "/var/www/html/mauticGIT-Test/themes/fresh-center/html/page.html.twig");
     }
 }
