@@ -496,6 +496,6 @@ class PluginController extends FormController
 
     public function getSourceContext(): Source
     {
-        return new Source("", "@bundles/PluginBundle/Controller/PluginController.php", "/var/www/mautic-ktn/app/bundles/PluginBundle/Controller/PluginController.php");
+        return new Source("", "@bundles/PluginBundle/Controller/PluginController.php", "/var/www/html/mauticGIT-Test/app/bundles/PluginBundle/Controller/PluginController.php");
     }
 }
