@@ -227,6 +227,6 @@ class __TwigTemplate_0f40e0d67d5fac2e54a5244d0dc524f5 extends Template
 
     public function getSourceContext(): Source
     {
-        return new Source("", "@MauticCore/Menu/admin.html.twig", "/var/www/mautic-ktn/app/bundles/CoreBundle/Resources/views/Menu/admin.html.twig");
+        return new Source("", "@MauticCore/Menu/admin.html.twig", "/var/www/html/mauticGIT-Test/app/bundles/CoreBundle/Resources/views/Menu/admin.html.twig");
     }
 }
