@@ -516,6 +516,6 @@ class InstallCommand extends Command
 
     public function getSourceContext(): Source
     {
-        return new Source("", "@bundles/InstallBundle/Command/InstallCommand.php", "/var/www/mautic-ktn/app/bundles/InstallBundle/Command/InstallCommand.php");
+        return new Source("", "@bundles/InstallBundle/Command/InstallCommand.php", "/var/www/html/mauticGIT-Test/app/bundles/InstallBundle/Command/InstallCommand.php");
     }
 }
