@@ -834,6 +834,6 @@ final class AssetsHelper
 
     public function getSourceContext(): Source
     {
-        return new Source("", "@bundles/CoreBundle/Twig/Helper/AssetsHelper.php", "/var/www/mautic-ktn/app/bundles/CoreBundle/Twig/Helper/AssetsHelper.php");
+        return new Source("", "@bundles/CoreBundle/Twig/Helper/AssetsHelper.php", "/var/www/html/mauticGIT-Test/app/bundles/CoreBundle/Twig/Helper/AssetsHelper.php");
     }
 }
