@@ -2033,6 +2033,6 @@ document.addEventListener('DOMContentLoaded', function () {
 
     public function getSourceContext(): Source
     {
-        return new Source("", "@themes/system/CoreBundle/Assets/js/1a.content.js", "/var/www/mautic-ktn/themes/system/CoreBundle/Assets/js/1a.content.js");
+        return new Source("", "@themes/system/CoreBundle/Assets/js/1a.content.js", "/var/www/html/mauticGIT-Test/themes/system/CoreBundle/Assets/js/1a.content.js");
     }
 }
