@@ -48,7 +48,7 @@ class __TwigTemplate_7c1ff29b03362b3a9abf6ef6320599cb extends Template
 @import \"mixins\";
 
 //== Logo
-//
+\$brand-primary: #2E5BFF !important;
 //## common logo color
 @mautic-logo-figure-width:                  32px;
 @mautic-logo-figure-circle-fill:            @mautic-primary;
@@ -1655,6 +1655,6 @@ class __TwigTemplate_7c1ff29b03362b3a9abf6ef6320599cb extends Template
 
     public function getSourceContext(): Source
     {
-        return new Source("", "@bundles/CoreBundle/Assets/css/app/less/variables.less", "/var/www/mautic-ktn/app/bundles/CoreBundle/Assets/css/app/less/variables.less");
+        return new Source("", "@bundles/CoreBundle/Assets/css/app/less/variables.less", "/var/www/html/mauticGIT-Test/app/bundles/CoreBundle/Assets/css/app/less/variables.less");
     }
 }
