@@ -877,6 +877,6 @@ class Page extends FormEntity implements TranslationEntityInterface, VariantEnti
 
     public function getSourceContext(): Source
     {
-        return new Source("", "@bundles/PageBundle/Entity/Page.php", "/var/www/mautic-ktn/app/bundles/PageBundle/Entity/Page.php");
+        return new Source("", "@bundles/PageBundle/Entity/Page.php", "/var/www/html/mauticGIT-Test/app/bundles/PageBundle/Entity/Page.php");
     }
 }
