@@ -527,6 +527,6 @@ class ResultController extends CommonFormController
 
     public function getSourceContext(): Source
     {
-        return new Source("", "@bundles/FormBundle/Controller/ResultController.php", "/var/www/mautic-ktn/app/bundles/FormBundle/Controller/ResultController.php");
+        return new Source("", "@bundles/FormBundle/Controller/ResultController.php", "/var/www/html/mauticGIT-Test/app/bundles/FormBundle/Controller/ResultController.php");
     }
 }
