@@ -861,6 +861,6 @@ class __TwigTemplate_6741d3fc28526759fa2a83d24a85db69 extends Template
 
     public function getSourceContext(): Source
     {
-        return new Source("", "@bundles/CoreBundle/Assets/css/libraries/font-awesome/less/variables.less", "/var/www/mautic-ktn/app/bundles/CoreBundle/Assets/css/libraries/font-awesome/less/variables.less");
+        return new Source("", "@bundles/CoreBundle/Assets/css/libraries/font-awesome/less/variables.less", "/var/www/html/mauticGIT-Test/app/bundles/CoreBundle/Assets/css/libraries/font-awesome/less/variables.less");
     }
 }
