@@ -39,7 +39,7 @@ class __TwigTemplate_dcf816f708feff70130e4d201258e3fa extends Template
     {
         $macros = $this->macros;
         // line 10
-        $___internal_parse_2_ = ('' === $tmp = \Twig\Extension\CoreExtension::captureOutput((function () use (&$context, $macros, $blocks) {
+        $___internal_parse_1_ = ('' === $tmp = \Twig\Extension\CoreExtension::captureOutput((function () use (&$context, $macros, $blocks) {
             // line 11
             $context["nameGetter"] = ((array_key_exists("nameGetter", $context)) ? (Twig\Extension\CoreExtension::default((isset($context["nameGetter"]) || array_key_exists("nameGetter", $context) ? $context["nameGetter"] : (function () { throw new RuntimeError('Variable "nameGetter" does not exist.', 11, $this->source); })()), "getName")) : ("getName"));
             // line 12
@@ -177,7 +177,7 @@ $context["variant"], "variants" =>                         // line 67
             yield from [];
         })())) ? '' : new Markup($tmp, $this->env->getCharset());
         // line 10
-        yield Twig\Extension\CoreExtension::spaceless($___internal_parse_2_);
+        yield Twig\Extension\CoreExtension::spaceless($___internal_parse_1_);
         yield from [];
     }
 
@@ -207,6 +207,6 @@ $context["variant"], "variants" =>                         // line 67
 
     public function getSourceContext(): Source
     {
-        return new Source("", "@MauticCore/Variant/index.html.twig", "/var/www/mautic-ktn/app/bundles/CoreBundle/Resources/views/Variant/index.html.twig");
+        return new Source("", "@MauticCore/Variant/index.html.twig", "/var/www/html/mauticGIT-Test/app/bundles/CoreBundle/Resources/views/Variant/index.html.twig");
     }
 }
