@@ -858,6 +858,6 @@ Mautic.updateFieldOperatorValue = function(field, action, valueOnChange, valueOn
 
     public function getSourceContext(): Source
     {
-        return new Source("", "@bundles/CoreBundle/Assets/js/6.forms.js", "/var/www/mautic-ktn/app/bundles/CoreBundle/Assets/js/6.forms.js");
+        return new Source("", "@bundles/CoreBundle/Assets/js/6.forms.js", "/var/www/html/mauticGIT-Test/app/bundles/CoreBundle/Assets/js/6.forms.js");
     }
 }
