@@ -433,6 +433,6 @@ return [
 
     public function getSourceContext(): Source
     {
-        return new Source("", "@bundles/CampaignBundle/Config/config.php", "/var/www/mautic-ktn/app/bundles/CampaignBundle/Config/config.php");
+        return new Source("", "@bundles/CampaignBundle/Config/config.php", "/var/www/html/mauticGIT-Test/app/bundles/CampaignBundle/Config/config.php");
     }
 }
