@@ -2382,6 +2382,6 @@ class EmailModel extends FormModel implements AjaxLookupModelInterface
 
     public function getSourceContext(): Source
     {
-        return new Source("", "@bundles/EmailBundle/Model/EmailModel.php", "/var/www/mautic-ktn/app/bundles/EmailBundle/Model/EmailModel.php");
+        return new Source("", "@bundles/EmailBundle/Model/EmailModel.php", "/var/www/html/mauticGIT-Test/app/bundles/EmailBundle/Model/EmailModel.php");
     }
 }
