@@ -1466,6 +1466,6 @@ class Asset extends FormEntity
 
     public function getSourceContext(): Source
     {
-        return new Source("", "@bundles/AssetBundle/Entity/Asset.php", "/var/www/mautic-ktn/app/bundles/AssetBundle/Entity/Asset.php");
+        return new Source("", "@bundles/AssetBundle/Entity/Asset.php", "/var/www/html/mauticGIT-Test/app/bundles/AssetBundle/Entity/Asset.php");
     }
 }
