@@ -657,6 +657,6 @@ class InputHelper
 
     public function getSourceContext(): Source
     {
-        return new Source("", "@bundles/CoreBundle/Helper/InputHelper.php", "/var/www/mautic-ktn/app/bundles/CoreBundle/Helper/InputHelper.php");
+        return new Source("", "@bundles/CoreBundle/Helper/InputHelper.php", "/var/www/html/mauticGIT-Test/app/bundles/CoreBundle/Helper/InputHelper.php");
     }
 }
