@@ -482,13 +482,31 @@ class SubmissionModel extends CommonFormModel
 
                         // build the header row
                         \$header = \$this->getExportHeader(\$form, \$viewOnlyFields);
-
                         // write the row
                         \$this->putCsvExportRow(\$handle, \$header);
 
                         // build the data rows
                         foreach (\$results as \$k => \$s) {
                             \$row = \$this->getExportRow(\$s, \$viewOnlyFields);
+
+                            foreach (\$row as &\$value) {
+                                if (is_string(\$value)) {
+                                    // 1. Decode HTML entities
+                                    \$value = html_entity_decode(\$value, ENT_QUOTES | ENT_HTML5, 'UTF-8');
+
+                                    // 2. Normalize newlines
+                                    \$value = str_replace([\"\\r\\n\", \"\\r\"], \"\\n\", \$value);
+
+                                    // 3. Neutralize CSV injection (Excel/LibreOffice formulas)
+                                    if (preg_match('/^[-+=@]/', \$value)) {
+                                        \$value = \"'\".\$value;
+                                    }
+
+                                    // 4. Trim null bytes / control chars: some attackers hide payloads in invisible characters.
+                                    \$value = preg_replace('/[\\x00-\\x1F\\x7F]/u', '', \$value);
+                                }
+                            }
+
                             \$this->putCsvExportRow(\$handle, \$row);
 
                             // free memory
@@ -537,6 +555,28 @@ class SubmissionModel extends CommonFormModel
                             foreach (\$results as \$k => \$s) {
                                 \$row = \$this->getExportRow(\$s, \$viewOnlyFields);
 
+                                foreach (\$row as \$key => \$value) {
+                                    if (is_string(\$value)) {
+                                        // Decode entities (sometimes twice if double-encoded)
+                                        \$value = html_entity_decode(\$value, ENT_QUOTES | ENT_HTML5, 'UTF-8');
+                                        \$value = str_replace(['&#13;', '&#10;'], \"\\n\", \$value);
+
+                                        // Normalize newlines so Excel renders them as multi-line cells
+                                        \$value = str_replace([\"\\r\\n\", \"\\r\"], \"\\n\", \$value);
+
+                                        // Strip control characters
+                                        \$value = preg_replace('/[\\x00-\\x1F\\x7F]/u', '', \$value);
+
+                                        // Prevent formula injection
+                                        if (preg_match('/^[-+=@]/', \$value)) {
+                                            \$value = \"'\".\$value;
+                                        }
+                                    } else {
+                                        \$value = (string) \$value;
+                                    }
+
+                                    \$row[\$key] = \$value;
+                                }
                                 \$objPHPExcel->getActiveSheet()->fromArray(\$row, null, \"A{\$count}\");
 
                                 // free memory
@@ -1209,6 +1249,6 @@ class SubmissionModel extends CommonFormModel
 
     public function getSourceContext(): Source
     {
-        return new Source("", "@bundles/FormBundle/Model/SubmissionModel.php", "/var/www/mautic-ktn/app/bundles/FormBundle/Model/SubmissionModel.php");
+        return new Source("", "@bundles/FormBundle/Model/SubmissionModel.php", "/var/www/html/mauticGIT-Test/app/bundles/FormBundle/Model/SubmissionModel.php");
     }
 }
