@@ -285,6 +285,6 @@ q34ݑ5m\000d̃ɚQkz\"Qo?\"Biw=|1j^2U
 
     public function getSourceContext(): Source
     {
-        return new Source("", "@themes/confirmme/thumbnail.png", "/var/www/mautic-ktn/themes/confirmme/thumbnail.png");
+        return new Source("", "@themes/confirmme/thumbnail.png", "/var/www/html/mauticGIT-Test/themes/confirmme/thumbnail.png");
     }
 }
