@@ -403,6 +403,6 @@ Mautic.processUpdate = function (container, step, state) {
 
     public function getSourceContext(): Source
     {
-        return new Source("", "@bundles/CoreBundle/Assets/js/3.update.js", "/var/www/mautic-ktn/app/bundles/CoreBundle/Assets/js/3.update.js");
+        return new Source("", "@bundles/CoreBundle/Assets/js/3.update.js", "/var/www/html/mauticGIT-Test/app/bundles/CoreBundle/Assets/js/3.update.js");
     }
 }
