@@ -1336,6 +1336,6 @@ body .facetwp-btn {
 
     public function getSourceContext(): Source
     {
-        return new Source("", "@themes/fresh-left/css/style.css", "/var/www/mautic-ktn/themes/fresh-left/css/style.css");
+        return new Source("", "@themes/fresh-left/css/style.css", "/var/www/html/mauticGIT-Test/themes/fresh-left/css/style.css");
     }
 }
