@@ -282,6 +282,6 @@ class __TwigTemplate_2ab66361133029197d2672ecefc29b96 extends Template
 
     public function getSourceContext(): Source
     {
-        return new Source("", "@themes/sunday/html/page.html.twig", "/var/www/mautic-ktn/themes/sunday/html/page.html.twig");
+        return new Source("", "@themes/sunday/html/page.html.twig", "/var/www/html/mauticGIT-Test/themes/sunday/html/page.html.twig");
     }
 }
