@@ -498,6 +498,6 @@ $context["loop"], "index", [], "any", false, false, false, 173), "class" => ((Tw
 
     public function getSourceContext(): Source
     {
-        return new Source("", "@MauticLead/Timeline/plugin_list.html.twig", "/var/www/mautic-ktn/app/bundles/LeadBundle/Resources/views/Timeline/plugin_list.html.twig");
+        return new Source("", "@MauticLead/Timeline/plugin_list.html.twig", "/var/www/html/mauticGIT-Test/app/bundles/LeadBundle/Resources/views/Timeline/plugin_list.html.twig");
     }
 }
