@@ -428,6 +428,6 @@ class __TwigTemplate_b860810daf11825f9d651da70f696e76 extends Template
 
     public function getSourceContext(): Source
     {
-        return new Source("", "@themes/fresh-left/html/page.html.twig", "/var/www/mautic-ktn/themes/fresh-left/html/page.html.twig");
+        return new Source("", "@themes/fresh-left/html/page.html.twig", "/var/www/html/mauticGIT-Test/themes/fresh-left/html/page.html.twig");
     }
 }
