@@ -432,6 +432,6 @@ class __TwigTemplate_0032c123a8eed1e584bc285f9728522e extends Template
 
     public function getSourceContext(): Source
     {
-        return new Source("", "@themes/fresh-wide/html/page.html.twig", "/var/www/mautic-ktn/themes/fresh-wide/html/page.html.twig");
+        return new Source("", "@themes/fresh-wide/html/page.html.twig", "/var/www/html/mauticGIT-Test/themes/fresh-wide/html/page.html.twig");
     }
 }
