@@ -245,6 +245,6 @@ $context["themeKey"], "class" => ("select-theme-link" . ((                    //
 
     public function getSourceContext(): Source
     {
-        return new Source("", "@MauticCore/Helper/theme_select.html.twig", "/var/www/mautic-ktn/app/bundles/CoreBundle/Resources/views/Helper/theme_select.html.twig");
+        return new Source("", "@MauticCore/Helper/theme_select.html.twig", "/var/www/html/mauticGIT-Test/app/bundles/CoreBundle/Resources/views/Helper/theme_select.html.twig");
     }
 }
