@@ -564,6 +564,6 @@ class __TwigTemplate_4464f7ef2af457bb1b5e8e819b2bb21d extends Template
 
     public function getSourceContext(): Source
     {
-        return new Source("", "@themes/goldstar/html/email.html.twig", "/var/www/mautic-ktn/themes/goldstar/html/email.html.twig");
+        return new Source("", "@themes/goldstar/html/email.html.twig", "/var/www/html/mauticGIT-Test/themes/goldstar/html/email.html.twig");
     }
 }
