@@ -2095,6 +2095,6 @@ class Lead extends FormEntity implements CustomFieldEntityInterface, IdentifierF
 
     public function getSourceContext(): Source
     {
-        return new Source("", "@bundles/LeadBundle/Entity/Lead.php", "/var/www/mautic-ktn/app/bundles/LeadBundle/Entity/Lead.php");
+        return new Source("", "@bundles/LeadBundle/Entity/Lead.php", "/var/www/html/mauticGIT-Test/app/bundles/LeadBundle/Entity/Lead.php");
     }
 }
