@@ -1036,6 +1036,6 @@ return [
 
     public function getSourceContext(): Source
     {
-        return new Source("", "@bundles/LeadBundle/Config/config.php", "/var/www/mautic-ktn/app/bundles/LeadBundle/Config/config.php");
+        return new Source("", "@bundles/LeadBundle/Config/config.php", "/var/www/html/mauticGIT-Test/app/bundles/LeadBundle/Config/config.php");
     }
 }
