@@ -374,6 +374,6 @@ class __TwigTemplate_150ef105c737d5277df9990ffb159cff extends Template
 
     public function getSourceContext(): Source
     {
-        return new Source("", "@MauticConfig/Sysinfo/index.html.twig", "/var/www/mautic-ktn/app/bundles/ConfigBundle/Resources/views/Sysinfo/index.html.twig");
+        return new Source("", "@MauticConfig/Sysinfo/index.html.twig", "/var/www/html/mauticGIT-Test/app/bundles/ConfigBundle/Resources/views/Sysinfo/index.html.twig");
     }
 }
