@@ -519,6 +519,6 @@ class TriggerModel extends CommonFormModel
 
     public function getSourceContext(): Source
     {
-        return new Source("", "@bundles/PointBundle/Model/TriggerModel.php", "/var/www/mautic-ktn/app/bundles/PointBundle/Model/TriggerModel.php");
+        return new Source("", "@bundles/PointBundle/Model/TriggerModel.php", "/var/www/html/mauticGIT-Test/app/bundles/PointBundle/Model/TriggerModel.php");
     }
 }
