@@ -267,6 +267,6 @@ mautic.notification.form.config.notification_email_addresses.tooltip = \"Add com
 
     public function getSourceContext(): Source
     {
-        return new Source("", "@bundles/NotificationBundle/Translations/en_US/messages.ini", "/var/www/mautic-ktn/app/bundles/NotificationBundle/Translations/en_US/messages.ini");
+        return new Source("", "@bundles/NotificationBundle/Translations/en_US/messages.ini", "/var/www/html/mauticGIT-Test/app/bundles/NotificationBundle/Translations/en_US/messages.ini");
     }
 }
